/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2013 by Tidalwave s.a.s. (http://tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker.archive;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import java.nio.file.Path;
import org.joda.time.DateTime;
import it.tidalwave.util.Finder;
import lombok.RequiredArgsConstructor;
import lombok.experimental.Wither;
import static lombok.AccessLevel.*;

/***********************************************************************************************************************
 *
 * Represents a single scan, containing a set of {@link ScanRecord}s.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public interface Scan 
  {
    public static final Class<Scan> Scan = Scan.class;
    
    /*******************************************************************************************************************
     * 
     * 
     ******************************************************************************************************************/
    @RequiredArgsConstructor(access = PROTECTED) @Immutable @Wither
    public static class Builder
      {
        public static interface ScanFactory // Lombok @Wither doesn't support builder subclasses
          {
            @Nonnull
            public Scan create (final @Nonnull DateTime beginScanDateTime);
          }

        private final ScanFactory scanFactory;
        
        private final DateTime beginScanDateTime;

        public Builder (final @Nonnull ScanFactory scanFactory) 
          {
            this(scanFactory, new DateTime());
          }
        
        @Nonnull
        public Scan build()
          {
            return scanFactory.create(beginScanDateTime);
          }
      }
    
    /*******************************************************************************************************************
     * 
     * 
     ******************************************************************************************************************/
    public static interface ScanRecordFinder extends Finder<ScanRecord>
      {
        @Nonnull
        public ScanRecordFinder withPath (@Nonnull Path path);  
      }
    
    /*******************************************************************************************************************
     * 
     * 
     * 
     ******************************************************************************************************************/
    @Nonnull
    public DateTime getBeginScanDateTime();
    
    /*******************************************************************************************************************
     * 
     * Adds a {@link ScanRecord}.
     * 
     ******************************************************************************************************************/
    @Nonnull
    public ScanRecord.Builder addScanRecord();
    
    /*******************************************************************************************************************
     * 
     * Retrieves contents.
     * 
     * @return  the {@link Finder} for the retrieval.
     * 
     ******************************************************************************************************************/
    @Nonnull
    public ScanRecordFinder findScanRecord();
  }
