/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2013 by Tidalwave s.a.s. (http://tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker.archive;

import javax.annotation.Nonnull;
import org.joda.time.DateTime;
import it.tidalwave.util.Finder;

/***********************************************************************************************************************
 *
 * The archive of {@link Scan}s.
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public interface ScanArchive
  {
    public static final Class<ScanArchive> ScanArchive = ScanArchive.class;

    public static final String ARCHIVE_FOLDER_NAME = ".it.tidalwave.solidblue";

    /*******************************************************************************************************************
     *
     * A {@link Finder} for {@link Scan}s.
     *
     ******************************************************************************************************************/
    public static interface ScanFinder extends Finder<Scan>
      {
        /***************************************************************************************************************
         *
         * Specifies a date & time for the search.
         *
         * @param  dateTime  the date & time
         * @return           the {@code Finder}
         *
         **************************************************************************************************************/
        @Nonnull
        public ScanFinder withDateTime (@Nonnull DateTime dateTime);
      }

    /*******************************************************************************************************************
     *
     * 
     * 
     ******************************************************************************************************************/
    @Nonnull
    public Scan.Builder addScan();

    /*******************************************************************************************************************
     *
     * Retrieves archived {@link Scan}s.
     *
     * @return  the {@link Finder} for the retrieval.
     *
     ******************************************************************************************************************/
    @Nonnull
    public Finder<Scan> find();
  }
