/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2013 by Tidalwave s.a.s. (http://tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.integritychecker.archive;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import java.nio.file.Path;
import it.tidalwave.actor.MessageSupport;
import it.tidalwave.actor.annotation.Message;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.ToString;
import static lombok.AccessLevel.PRIVATE;

/***********************************************************************************************************************
 * 
 * @stereotype Message
 * 
 * A message for notifying that a new scan archive has been created.
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Message @Immutable 
@RequiredArgsConstructor(access=PRIVATE) @EqualsAndHashCode(callSuper=false) @ToString(callSuper=false)
public class ScanArchiveCreatedMessage extends MessageSupport
  {
    @Nonnull @Getter
    private final Path folder;  
    
    @Nonnull
    public static ScanArchiveCreatedMessage forFolder (final @Nonnull Path folder)
      {
        if (!folder.toFile().isDirectory())
          {
            throw new IllegalArgumentException("Must be a directory: " + folder);
          }
         
        return new ScanArchiveCreatedMessage(folder);
      }    
  }
